==> 0.0.1.tar.gz: android/src/main/java/com/xwtec/wolfflashlight/WolfflashlightPlugin.java <==
package com.xwtec.wolfflashlight;

import android.app.Activity;
import android.content.Context;
import android.content.pm.PackageManager;
import android.hardware.Camera;
import android.hardware.camera2.CameraAccessException;
import android.hardware.camera2.CameraCharacteristics;
import android.hardware.camera2.CameraManager;
import android.os.Build;

import androidx.annotation.NonNull;
import androidx.annotation.RequiresApi;

import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.embedding.engine.plugins.activity.ActivityAware;
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;

/**
 * WolfflashlightPlugin
 */
@RequiresApi(api = Build.VERSION_CODES.LOLLIPOP)
public class WolfflashlightPlugin implements FlutterPlugin, MethodCallHandler, ActivityAware {
    /// The MethodChannel that will the communication between Flutter and native Android
    ///
    /// This local reference serves to register the plugin with the Flutter Engine and unregister it
    /// when the Flutter Engine is detached from the Activity
    private MethodChannel channel;

    private Boolean hasFlashlight;

    private Camera camera;

    /**
     * using with camera2. sdk >= 23
     */
    private CameraManager cameraManager;
    private String cameraId;

    Activity activity;
    Context context;


    @Override
    public void onAttachedToEngine(@NonNull FlutterPluginBinding flutterPluginBinding) {
        channel = new MethodChannel(flutterPluginBinding.getBinaryMessenger(), "wolfflashlight");
        channel.setMethodCallHandler(this);
        context = flutterPluginBinding.getApplicationContext();
        initFlashlight();
    }

    @Override
    public void onMethodCall(@NonNull MethodCall call, @NonNull Result result) {
        if (call.method.equals("getPlatformVersion")) {
            result.success("Android " + android.os.Build.VERSION.RELEASE);
        } else if (call.method.equals("hasFlashlight")) {
            result.success(hasFlashlight);
        } else if (call.method.equals("lightOn")) {
            turnLight(true);
            result.success(null);
        } else if (call.method.equals("lightOff")) {
            turnLight(false);
            result.success(null);
        } else if (call.method.equals("lightFlash")) {
            result.success(null);
        } else {
            result.notImplemented();
        }
    }

    @Override
    public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {
        channel.setMethodCallHandler(null);
    }

    private void initFlashlight() {
        hasFlashlight = false;

        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.M) {
            Activity activity = this.activity;
            cameraManager = (CameraManager) activity.getSystemService(Context.CAMERA_SERVICE);
            try {
                for (String id : cameraManager.getCameraIdList()) {
                    CameraCharacteristics characteristics = cameraManager.getCameraCharacteristics(id);
                    Integer facing = characteristics.get(CameraCharacteristics.LENS_FACING);

                    if (facing != null && facing.equals(CameraCharacteristics.LENS_FACING_BACK)) {
                        cameraId = id;
                        hasFlashlight = characteristics.get(CameraCharacteristics.FLASH_INFO_AVAILABLE);
                    }
                }
            } catch (NullPointerException e) {
                // ignore it
            } catch (Exception e) {
                e.printStackTrace();
            }
        } else {
            this.camera = this.getCamera();
            hasFlashlight = context.getPackageManager().hasSystemFeature(PackageManager.FEATURE_CAMERA_FLASH);
        }
    }

    private Camera getCamera() {
        try {
            return Camera.open();
        } catch (Exception e) {
            System.out.println("Failed to get camera : " + e.toString());
            return null;
        }
    }

    private void turnLight(boolean on) {
        if (!hasFlashlight) {
            return;
        } else if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.M) {
            try {
                cameraManager.setTorchMode(cameraId, on);
            } catch (CameraAccessException e) {
                // do nothing.
            }
        } else {
            if (camera == null) {
                return;
            }
            Camera.Parameters params = camera.getParameters();
            params.setFlashMode(on ? Camera.Parameters.FLASH_MODE_TORCH : Camera.Parameters.FLASH_MODE_OFF);
            camera.setParameters(params);
            camera.startPreview();
        }
    }


    @Override
    public void onAttachedToActivity(@NonNull ActivityPluginBinding binding) {
        this.activity = binding.getActivity();
    }

    @Override
    public void onDetachedFromActivityForConfigChanges() {
        activity = null;
    }

    @Override
    public void onReattachedToActivityForConfigChanges(@NonNull ActivityPluginBinding binding) {
        activity = binding.getActivity();
    }

    @Override
    public void onDetachedFromActivity() {
        activity = null;
    }
}

==> 0.0.2.tar.gz: android/src/main/java/com/xwtec/wolfflashlight/WolfflashlightPlugin.java <==
package com.xwtec.wolfflashlight;

import android.app.Activity;
import android.content.Context;
import android.content.pm.PackageManager;
import android.hardware.Camera;
import android.hardware.camera2.CameraAccessException;
import android.hardware.camera2.CameraCharacteristics;
import android.hardware.camera2.CameraManager;
import android.os.Build;

import androidx.annotation.NonNull;
import androidx.annotation.RequiresApi;

import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.embedding.engine.plugins.activity.ActivityAware;
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry;

/**
 * WolfflashlightPlugin
 */
@RequiresApi(api = Build.VERSION_CODES.LOLLIPOP)
public class WolfflashlightPlugin implements FlutterPlugin, MethodCallHandler {
    /// The MethodChannel that will the communication between Flutter and native Android
    ///
    /// This local reference serves to register the plugin with the Flutter Engine and unregister it
    /// when the Flutter Engine is detached from the Activity
    private MethodChannel channel;

    private Boolean hasFlashlight;

    private Camera camera;

    /**
     * using with camera2. sdk >= 23
     */
    private CameraManager cameraManager;
    private String cameraId;

    Context context;



    @Override
    public void onAttachedToEngine(@NonNull FlutterPluginBinding flutterPluginBinding) {
        channel = new MethodChannel(flutterPluginBinding.getBinaryMessenger(), "wolfflashlight");
        channel.setMethodCallHandler(this);
        context = flutterPluginBinding.getApplicationContext();
        initFlashlight();
    }

    @Override
    public void onMethodCall(@NonNull MethodCall call, @NonNull Result result) {
        if (call.method.equals("getPlatformVersion")) {
            result.success("Android " + android.os.Build.VERSION.RELEASE);
        } else if (call.method.equals("hasFlashlight")) {
            result.success(hasFlashlight);
        } else if (call.method.equals("lightOn")) {
            turnLight(true);
            result.success(null);
        } else if (call.method.equals("lightOff")) {
            turnLight(false);
            result.success(null);
        } else if (call.method.equals("lightFlash")) {
            lightFlash();
            result.success(null);
        } else {
            result.notImplemented();
        }
    }

    @Override
    public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {
        channel.setMethodCallHandler(null);
    }

    private void initFlashlight() {
        hasFlashlight = false;

        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.M) {
//            Activity activity = this.activity;
            cameraManager = (CameraManager) context.getSystemService(Context.CAMERA_SERVICE);
//            cameraManager = (CameraManager) activity.getSystemService(Context.CAMERA_SERVICE);
            try {
                for (String id : cameraManager.getCameraIdList()) {
                    CameraCharacteristics characteristics = cameraManager.getCameraCharacteristics(id);
                    Integer facing = characteristics.get(CameraCharacteristics.LENS_FACING);

                    if (facing != null && facing.equals(CameraCharacteristics.LENS_FACING_BACK)) {
                        cameraId = id;
                        hasFlashlight = characteristics.get(CameraCharacteristics.FLASH_INFO_AVAILABLE);
                    }
                }
            } catch (NullPointerException e) {
                // ignore it
            } catch (Exception e) {
                e.printStackTrace();
            }
        } else {
            this.camera = this.getCamera();
            hasFlashlight = context.getPackageManager().hasSystemFeature(PackageManager.FEATURE_CAMERA_FLASH);
        }
    }

    private Camera getCamera() {
        try {
            return Camera.open();
        } catch (Exception e) {
            System.out.println("Failed to get camera : " + e.toString());
            return null;
        }
    }

    private void turnLight(boolean on) {
        if (!hasFlashlight) {
            return;
        } else if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.M) {
            try {
                cameraManager.setTorchMode(cameraId, on);
            } catch (CameraAccessException e) {
                // do nothing.
            }
        } else {
            if (camera == null) {
                return;
            }
            Camera.Parameters params = camera.getParameters();
            params.setFlashMode(on ? Camera.Parameters.FLASH_MODE_TORCH : Camera.Parameters.FLASH_MODE_OFF);
            camera.setParameters(params);
            camera.startPreview();
        }
    }

    private void lightFlash(){
        turnLight(true);
        try {
            Thread.sleep(10);
        } catch (InterruptedException e) {
            e.printStackTrace();
        }
        turnLight(false);
    }
}
